@@ -76,6 +76,10 @@
 
 #ifndef XvExtension
 void viaInitVideo(ScreenPtr pScreen) {}
+void viaExitVideo(ScrnInfoPtr pScrn) {}
+void viaSaveVideo(ScrnInfoPtr pScrn) {}
+void viaRestoreVideo(ScrnInfoPtr pScrn) {}
+void VIAVidAdjustFrame(ScrnInfoPtr pScrn, int x, int y) {}
 #else
 
 static vidCopyFunc viaFastVidCpy = NULL;
@@ -1101,8 +1105,8 @@ viaPutImage(
 		REGION_COPY(pScrn->pScreen, &pPriv->clip, clipBoxes);    
 		if (pPriv->autoPaint) 
 		    xf86XVFillKeyHelper(pScrn->pScreen, pPriv->colorKey, clipBoxes); 
-	    } 
-		
+	    }		
+
 	    /*
 	     *  Update video overlay
 	     */
